@@ -1,14 +1,15 @@
+import numpy as np
 import torch
 from torch import nn
 
 
-class ConstantOfShape(nn.Module):
+class Constant(nn.Module):
     def __init__(self, constant):
         super().__init__()
-        self.constant = torch.from_numpy(constant)
+        self.register_buffer("constant", torch.from_numpy(np.copy(constant)))
 
-    def forward(self, shape: torch.Tensor):
-        return self.constant * torch.ones(*shape)
+    def forward(self):
+        return self.constant
 
     def extra_repr(self) -> str:
         return "constant={}".format(self.constant)
