@@ -14,4 +14,8 @@ class Pad(Operator):
             pads = self.padding
         elif pads is None:
             raise TypeError("forward() missing 1 required positional argument: 'pads'")
-        return F.pad(input, list(pads), mode=self.mode, value=value)
+        out = F.pad(input, list(pads), mode=self.mode, value=value)
+        return out
+
+    def extra_repr(self) -> str:
+        return "mode={}, padding={}".format(self.mode, self.padding)
